@@ -57,7 +57,7 @@ void PortalMonitor::connectivityChanged(NetworkManager::Connectivity connectivit
         notification->setText(i18n("You need to log in to this network"));
         notification->sendEvent();
         connect(notification, &KNotification::action1Activated, this, [] () {
-            QDesktopServices::openUrl(QUrl("http://kde.org"));
+            QDesktopServices::openUrl(QUrl("http://networkcheck.kde.org"));
         });
     }
 }
