@@ -54,6 +54,7 @@ NetworkModelItem::NetworkModelItem(QObject *parent)
     : QObject(parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_deviceState(NetworkManager::Device::UnknownState)
+    , m_detailsValid(false)
     , m_duplicate(false)
     , m_mode(NetworkManager::WirelessSetting::Infrastructure)
     , m_securityType(NetworkManager::NoneSecurity)
@@ -61,6 +62,8 @@ NetworkModelItem::NetworkModelItem(QObject *parent)
     , m_slave(false)
     , m_type(NetworkManager::ConnectionSettings::Unknown)
     , m_vpnState(NetworkManager::VpnConnection::Unknown)
+    , m_rxBytes(0)
+    , m_txBytes(0)
 {
 }
 
@@ -68,6 +71,7 @@ NetworkModelItem::NetworkModelItem(const NetworkModelItem *item, QObject *parent
     : QObject(parent)
     , m_connectionPath(item->connectionPath())
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
+    , m_detailsValid(false)
     , m_duplicate(true)
     , m_mode(item->mode())
     , m_name(item->name())
@@ -78,6 +82,8 @@ NetworkModelItem::NetworkModelItem(const NetworkModelItem *item, QObject *parent
     , m_type(item->type())
     , m_uuid(item->uuid())
     , m_vpnState(NetworkManager::VpnConnection::Unknown)
+    , m_rxBytes(0)
+    , m_txBytes(0)
 {
 }
 
@@ -117,6 +123,9 @@ void NetworkModelItem::setConnectionState(NetworkManager::ActiveConnection::Stat
 
 QStringList NetworkModelItem::details() const
 {
+    if (!m_detailsValid) {
+        updateDetails();
+    }
     return m_details;
 }
 
@@ -403,6 +412,26 @@ void NetworkModelItem::setVpnType(const QString &type)
     m_vpnType = type;
 }
 
+qulonglong NetworkModelItem::rxBytes() const
+{
+    return m_rxBytes;
+}
+
+void NetworkModelItem::setRxBytes(qulonglong bytes)
+{
+    m_rxBytes = bytes;
+}
+
+qulonglong NetworkModelItem::txBytes() const
+{
+    return m_txBytes;
+}
+
+void NetworkModelItem::setTxBytes(qulonglong bytes)
+{
+    m_txBytes = bytes;
+}
+
 bool NetworkModelItem::operator==(const NetworkModelItem *item) const
 {
     if (!item->uuid().isEmpty() && !uuid().isEmpty()) {
@@ -418,8 +447,14 @@ bool NetworkModelItem::operator==(const NetworkModelItem *item) const
     return false;
 }
 
-void NetworkModelItem::updateDetails()
+void NetworkModelItem::invalidateDetails()
 {
+    m_detailsValid = false;
+}
+
+void NetworkModelItem::updateDetails() const
+{
+    m_detailsValid = true;
     m_details.clear();
 
     if (itemType() == NetworkModelItem::UnavailableConnection) {
